@@ -30,6 +30,7 @@ import sys
 import tempfile
 import time
 import urllib
+import urlparse
 import zipfile
 
 try:
@@ -357,14 +358,27 @@ class ConfigStack(object):
         deploy_data = self._resolve_inherited(deploy_data)
         return Deployment(key, deploy_data, self.include_dirs)
 
-    def load(self):
+    def load(self, urlopen=urllib.urlopen):
         data = {}
         include_dirs = []
         for fp in self.config_files:
             if not path_exists(fp):
-                self.log.warning("Config file not found %s", fp)
-                raise ErrorExit()
-            include_dirs.append(dirname(abspath(fp)))
+                # If the config file path is a URL, fetch it and use it.
+                if urlparse.urlparse(fp).scheme:
+                    response = urlopen(fp)
+                    if response.getcode() == 200:
+                        temp = tempfile.NamedTemporaryFile(delete=True)
+                        shutil.copyfileobj(response, temp)
+                        temp.flush()
+                        fp = temp.name
+                    else:
+                        self.log.warning("Could not retrieve %s", fp)
+                        raise ErrorExit()
+                else:
+                    self.log.warning("Config file not found %s", fp)
+                    raise ErrorExit()
+            else:
+                include_dirs.append(dirname(abspath(fp)))
             with open(fp) as fh:
                 try:
                     d = yaml_load(fh.read())
@@ -845,7 +859,7 @@ class Deployment(object):
             os.mkdir(self.series_path)
         for charm in self.get_charms():
             if charm.is_local():
-                if self.charm.exists():
+                if charm.exists():
                     if no_local_mods:
                         if charm.is_modified():
                             self.log.warning(
